@@ -620,7 +620,7 @@ class BaseConfig():
                                    help='Override db hmac key '
                                    '  '
                                    '  '
-                                   'The hmac key is used for cryptographic hashing '
+                                   'The hmac key that is used for cryptographic hashing '
                                    'during creation of HLL sets. Override what is '
                                    'set in hllworker database here. '
                                    '  '
@@ -628,6 +628,16 @@ class BaseConfig():
                                    'Remember to re-use the same hmac key for any '
                                    'consecutive update of HLL sets. '
                                    '  '
+                                   '  '
+                                   'The crypt.salt variable can also be set (temporarily or permanently) in the '
+                                   'hll worker database itself. '
+                                   '  '
+                                   'Example:'
+                                   '```sql'
+                                   'ALTER DATABASE hllworkerdb SET crypt.salt = \'CRYPTSALT\';'
+                                   '```'
+                                   '  '
+                                   '  '
                                    'Further information is available in the [YFCC HLL tutorial][2]. '
                                    '  '
                                    '[2]: https://lbsn.vgiscience.org/tutorial/yfcc-geohash/#prepare-query-and-cryptographic-hashing',
